.. math::
    | \sum_i (f_i(\mathbf{\bar{x}}) - f_i(\mathbf{x}^\star)) |

where :math:`f_i` is agent i's local cost function,
:math:`\mathbf{\bar{x}}` is the mean x across all *agents*,
and :math:`\mathbf{x}^\star` is the optimal x defined in the *problem*.
